@@ -3,11 +3,12 @@ import csv
 import logging
 import os
 from enum import Enum
+from functools import cached_property
 from typing import List, Optional
 
 from scipy.spatial import KDTree
-from rnapolis.metareader import read_metadata
 
+from rnapolis.metareader import read_metadata
 from rnapolis.parser import read_3d_structure
 from rnapolis.tertiary import Atom, Residue3D
 
@@ -25,7 +26,7 @@ class AtomType(Enum):
     O = "O"
     P = "P"
 
-    @property
+    @cached_property
     def radius(self) -> float:
         if self.value == "C":
             return CARBON_RADIUS
